import React from 'react'

import {
  Box,
  Button,
  Divider,
  HStack,
  Text,
  useDisclosure,
  VStack,
} from '@chakra-ui/react'

import { useParams } from '@redwoodjs/router'

import { Animations } from 'src/pages/animations'
import { Implementations } from 'src/pages/implementations'
import { GetPatternQuery } from '../query-builder'
import { FormalizationList } from './formalizations-list'
import { EditPatternModal } from '../edit-pattern'
import { DeletePatternButton } from '../delete-pattern'
import { useTranslation } from 'react-i18next'
import { capitalize } from 'lodash'
import { UserManualButton } from '../user-manual-button'

export const PatternDetails = () => {
  const { t } = useTranslation()
  const { id } = useParams()

  const getPatternQuery = GetPatternQuery.useQuery({ id })
  const pattern = getPatternQuery.data
  const editPatternDisclosure = useDisclosure()

  if (!pattern) {
    return null
  }

  return (
    <>
      <VStack w="full">
        <VStack w="80%">
          <VStack display="flex" alignItems="start" px="2" minW="80vw">
            <Text fontWeight="bold" fontSize="x-large">
              {pattern.name}
            </Text>
            <Text wordBreak="break-word">{pattern.description}</Text>
          </VStack>
          <VStack w="full" justifyContent="center" spacing="8">
            <VStack alignItems="flex-start">
              <Text pl="2" fontWeight="bold">
                {capitalize(t('implementations'))}
              </Text>
              <Implementations patternId={pattern.id} />
            </VStack>
            <VStack alignItems="flex-start">
              <Text pl="2" fontWeight="bold">
                {capitalize(t('animations'))}
              </Text>
              <Animations patternId={pattern.id} />
            </VStack>
          </VStack>
          <Divider py="4" />
          <VStack w="full" alignItems="flex-start">
            <Text fontWeight="bold">
              {capitalize(t('formalizations_formalizations'))}
            </Text>
            <FormalizationList patternId={pattern.id} />
          </VStack>
          <Divider py="4" />
          <HStack w="full" display="flex" justifyContent="space-between" py="4">
            <UserManualButton />
            <HStack>
              <Button onClick={editPatternDisclosure.onOpen}>
                {capitalize(t('edit'))}
              </Button>
              <DeletePatternButton pattern={pattern}>
                <Button colorScheme="red">
                  {capitalize(
                    t('patterns_delete_pattern_confirmation_modal_header')
                  )}
                </Button>
              </DeletePatternButton>
            </HStack>
          </HStack>
        </VStack>
      </VStack>
      {editPatternDisclosure.isOpen && (
        <EditPatternModal
          disclosure={editPatternDisclosure}
          pattern={pattern}
        />
      )}
    </>
  )
}
