import { Button, ButtonProps, Icon, Link } from '@chakra-ui/react'
import { capitalize } from 'lodash'
import React from 'react'
import { useTranslation } from 'react-i18next'
import { FaDownload } from 'react-icons/fa'
import { match } from 'ts-pattern'

export type UserManualButtonProps = Partial<ButtonProps>

export const UserManualButton = ({ ...props }: UserManualButtonProps) => {
  const { t, i18n } = useTranslation()
  const currentLanguage = i18n.language
  const docName = match(currentLanguage)
    .with('es', () => 'ES manual de usuario.pdf')
    .with('en', () => 'EN manual de usuario.pdf')
    .otherwise(() => 'ES manual de usuario.pdf')

  return (
    <Link href={`/docs/${docName}`} download>
      <Button
        variant="outline"
        borderColor="gray.600"
        color="gray.600"
        rightIcon={<Icon as={FaDownload} />}
        {...props}
      >
        {capitalize(t('user_manual'))}
      </Button>
    </Link>
  )
}
