import { AxiosError } from 'axios'
import { useQuery as useRQ, UseQueryOptions } from 'react-query'
import { Report } from 'src/models'

import axiosService from 'src/services/axios-service'

export namespace GetReportQuery {
  export type Params = { id: Report['id'] }

  export type Response = Report

  export const key = ['reports']

  export const getKey = (params: Params) => [...key, params]

  export const queryFn = (params: Params) =>
    axiosService.get<Response>(`/reports/${params.id}`).then((res) => res.data)

  export const useQuery = <Select = Response>(
    params: Params,
    options: UseQueryOptions<Response, AxiosError, Select> = {}
  ) => {
    return useRQ(getKey(params), () => queryFn(params), {
      ...options,
    })
  }
}
