import React from 'react'

import {
  HStack,
  Icon,
  IconButton,
  Table,
  TableCaption,
  TableContainer,
  Tbody,
  Td,
  Text,
  Th,
  Thead,
  Tooltip,
  Tr,
  VStack,
} from '@chakra-ui/react'
import { Link, routes, useParams } from '@redwoodjs/router'
import { GetImplementationQuery } from '../implementations/query-builder/get-implementation-query'
import { GetReportsByImplementationIdQuery } from './query-builder'
import { DateUtils } from 'src/utils/date-utils'
import { Implementation, Report } from 'src/models'
import { FaEye, FaTrash } from 'react-icons/fa'
import { useTranslation } from 'react-i18next'
import { capitalize } from 'lodash'
import { DeleteReportButton } from './delete-report-button/delete-report-button'

export const Reports = () => {
  const { t } = useTranslation()
  const { implementationId } = useParams()

  const implementationQuery = GetImplementationQuery.useQuery({
    id: implementationId,
  })

  const reportsQuery = GetReportsByImplementationIdQuery.useQuery({
    id: implementationId,
  })

  const tableHeaders = [capitalize(t('date')), capitalize(t('name')), '']

  return (
    <VStack alignItems="flex-start" spacing="2">
      <Text fontWeight="bold" fontSize="x-large" px="1">
        {capitalize(t('reports_table_title'))} {implementationQuery.data?.name}
      </Text>
      <TableContainer>
        <Table variant="striped" size="lg" minW="80vw">
          <TableCaption>
            {capitalize(t('reports_available_reports'))}
          </TableCaption>
          <Thead>
            <Tr>
              {tableHeaders.map((header, index) => (
                <Th color="gray.500" key={`th-${index}`}>
                  {header}
                </Th>
              ))}
            </Tr>
          </Thead>
          <Tbody>
            {reportsQuery.data?.map((report, index) => (
              <Tr key={`report-${report.name}-${index}`}>
                <Td>{DateUtils.formatLocalDateTime(report.createdDate)}</Td>
                <Td>
                  {/* @ts-ignore -- TODO */}
                  <Link to={routes.report({ id: report.id })}>
                    {report.name}
                  </Link>
                </Td>
                <Td>
                  <ActionsRow
                    report={report}
                    implementationId={implementationId}
                  />
                </Td>
              </Tr>
            ))}
          </Tbody>
        </Table>
      </TableContainer>
    </VStack>
  )
}

const ActionsRow = ({
  report,
  implementationId,
}: {
  report: Report
  implementationId: Implementation['id']
}) => {
  const { t } = useTranslation()
  return (
    <HStack justifyContent="flex-end">
      {/* @ts-ignore -- TODO */}
      <Link to={routes.report({ id: report.id })}>
        <Tooltip
          shouldWrapChildren
          hasArrow
          label={<Text>{capitalize(t('view'))}</Text>}
        >
          <IconButton
            aria-label="ver detalles de reporte"
            variant="unstyled"
            icon={<Icon as={FaEye} />}
          />
        </Tooltip>
      </Link>
      <DeleteReportButton report={report} implementationId={implementationId}>
        <IconButton
          aria-label="delete animation"
          variant="unstyled"
          icon={<Icon as={FaTrash} />}
        />
      </DeleteReportButton>
    </HStack>
  )
}
